#!/usr/bin/env perl
use strict;
use warnings;

use Test::More tests => 21;
use Test::NoWarnings;
use Data::Dump 'pp';

BEGIN { use_ok('List::Index' => 'rangematch'); }

for (
	[   q      =>          'q'],
	['#foo.!$' =>          '\#foo\.\!\$'],
	[    -q    =>            '(?:(?![q-z])|q)'],
	[    -qqq  =>            '(?:(?![q-z])|q(?![q-z])|qq(?![q-z])|qqq)'],
	[  'q-'    =>    '[q-z]'],
	['qqq-'    => '(?:[r-z]|q[r-z]|qq[q-z])'],
	[  'q-x'   =>    '[q-x]'],
	[  'q-q'   =>          'q'],
	[ 'qq-qq'  =>                 'qq'],
	[ 'qq-qqx' =>                                 '(?:qq(?![x-z])|qqx)'],
	[  'q-qx'  =>                      '(?:q(?![x-z])|qx)'],
	['qqq-xxx' => '(?:[r-w]|q[r-z]|qq[q-z]|x(?![x-z])|xx(?![x-z])|xxx)'],
	['qqq-xqq' => '(?:[r-w]|q[r-z]|qq[q-z]|x(?![q-z])|xq(?![q-z])|xqq)'],
	['qqq-xq'  => '(?:[r-w]|q[r-z]|qq[q-z]|x(?![q-z])|xq)'],
	[ 'qq-xqq' => '(?:[r-w]|q[q-z]|'   .  'x(?![q-z])|xq(?![q-z])|xqq)'],
	[  'q-xxx' =>                '(?:[q-w]|x(?![x-z])|xx(?![x-z])|xxx)'],
	['qqq-x'   => '(?:[r-x]|q[r-z]|qq[q-z])'],
	['qaa-qb'  =>              '(?:qa[a-z]|qb)'],
	['qqq-q'   =>       '(?:q[r-z]|qq[q-z])'],
) {
	my ($in, $out) = @$_;
	is(eval { rangematch($in) }, "(?i-xsm:^$out)", $in);
	diag($@) if $@;
}

